# qaviton helpers
![logo](https://www.qaviton.com/wp-content/uploads/logo-svg.svg)  
[![version](https://img.shields.io/pypi/v/qaviton_helpers.svg)](https://pypi.python.org/pypi)
[![open issues](https://img.shields.io/github/issues/qaviton/qaviton_helpers)](https://github/issues-raw/qaviton/qaviton_helpers)
[![downloads](https://img.shields.io/pypi/dm/qaviton_helpers.svg)](https://pypi.python.org/pypi)
![code size](https://img.shields.io/github/languages/code-size/qaviton/qaviton_helpers)  
a collection of nice objects and functions to make things simple
